slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetExtract

Gets the extraction strategy used by the PEP object.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetExtract(PEP pep,PEPExtract *extract)

Not Collective

### Input Parameter

| pep | - the eigensolver context

### Output Parameter

| extract | - extraction strategy

### See Also

PEPSetExtract(), PEPExtract

### Level

intermediate

### Location

src/pep/interface/pepopts.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages